#
# spec file for package nethack
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nethack
Version:        3.4.3
Release:        8.1
Summary:        Turn-based role-playing game
License:        NGPL
Group:          Amusements/Games/RPG
URL:            https://www.nethack.org
Source0:        nethack-343-src.tar.bz2
Source1:        nethack-rpmlintrc
# PATCH-FIX-UPSTREAM nethack-escapes-revamp.patch boo#1239138
Patch0:         nethack-escapes-revamp.patch
# PATCH-FIX-UPSTREAM nethack-WINCHAIN-a-framework-allowing-multiple-processors-be.patch boo#1245527
Patch1:         nethack-WINCHAIN-a-framework-allowing-multiple-processors-be.patch
# PATCH-FIX-UPSTREAM nethack-address-H4266-build-problem-with-clang-Modules.patch boo#1245527
Patch2:         nethack-address-H4266-build-problem-with-clang-Modules.patch
# PATCH-FIX-UPSTREAM nethack-tty-xputc.patch boo#1245527
Patch3:         nethack-tty-xputc.patch
# PATCH-FIX-UPSTREAM nethack-gcc15-1.patch boo#1245527
Patch4:         nethack-gcc15-1.patch
# PATCH-FIX-OPENSUSE nethack-config.patch Adapt build to openSUSE systems
Patch50:        nethack-config.patch
# PATCH-FIX-OPENSUSE nethack-decl.patch Do not redeclare system interfaces
Patch51:        nethack-decl.patch
# PATCH-FIX-OPENSUSE nethack-escape-char.patch
Patch52:        nethack-escape-char.patch
# PATCH-FIX-OPENSUSE nethack-secure.patch Handle SECURE in recover utility
Patch53:        nethack-secure.patch
# PATCH-FIX-OPENSUSE nethack-gzip.patch Use gzip compression
Patch54:        nethack-gzip.patch
# PATCH-FIX-OPENSUSE nethack-reproducible.patch boo#1047218
Patch55:        nethack-reproducible.patch
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  groff
BuildRequires:  ncurses-devel
Requires:       gzip
Requires(pre):  user(games) group(games)
Requires(pre):  permissions
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NetHack is a turn-based role-playing game with complex game mechanics.
Descent into the Mazes of Menace and retrieve the Amulet of Yendor. Play
as different character classes, such as fighter, wizard, rogue and others.
Persist against various monsters and defeat the Wizard of Yendor.

This package contains the text interface.

%prep
%setup
%patch -P0
%patch -P1 -p1
%patch -P2 -p1
%patch -P3 -p1
%patch -P4
%patch -P50
%patch -P51
%patch -P52
%patch -P53
%patch -P54
%patch -P55 -p1

%build
# copy Makefiles and add optimization flags
sh sys/unix/setup.sh
sed -i "s/^CFLAGS.*/& %{optflags}/" Makefile dat/Makefile doc/Makefile src/Makefile util/Makefile

# The Makefiles do not track dependencies correctly, which can result
# in link errors on parallel builds. Prevent this by building the object
# files for makedefs first.
%make_build -C src monst.o
%make_build -C src objects.o
%make_build -C src dlb.o

# Build the game binary, then some data files. Finally build all
# remaining default targets. Although 'all' covers the first three
# make calls as well, we have to resort to sequential building
# to make it work.
%make_build nethack
%make_build dungeon
%make_build spec_levs
%make_build all

# We also package a nicely formatted manual in PostScript format. It
# is not covered by 'all', so build it here.
%make_build -C doc Guidebook.ps

%install
# directories
install -d %{buildroot}%{_prefix}/lib/nethack/
install -d %{buildroot}%{_prefix}/games
install -d %{buildroot}%{_datadir}/games/nethack
install -d %{buildroot}/%{_mandir}/man6/
# game directory
install -d %{buildroot}%{_localstatedir}/games/nethack/
install -d %{buildroot}%{_localstatedir}/games/nethack/save/
for file in logfile paniclog perm record ; do
	touch %{buildroot}%{_localstatedir}/games/nethack/$file
done
# binaries
install src/nethack %{buildroot}%{_prefix}/lib/nethack/
# options
install dat/options %{buildroot}%{_prefix}/lib/nethack/
# man pages
install doc/{nethack,lev_comp,dlb,dgn_comp,recover}.6 %{buildroot}/%{_mandir}/man6/
# common data
install dat/nhdat %{buildroot}%{_datadir}/games/nethack/
install dat/license %{buildroot}%{_datadir}/games/nethack/
# main launcher script
install -d %{buildroot}%{_bindir}
install sys/unix/nethack.sh %{buildroot}%{_bindir}/nethack
# utils
install util/{dgn_comp,dlb,lev_comp,makedefs,recover} %{buildroot}%{_prefix}/lib/nethack/

%fdupes -s %{buildroot}%{_datadir}/games/nethack/license

%post
%set_permissions

%verifyscript
%verify_permissions -e /usr/lib/nethack/nethack

%files
%defattr(0644,root,root)
%license dat/license
%doc doc/fixes*
%doc doc/Guidebook.ps
%doc doc/Guidebook.txt
%attr(0755,-,-) %{_bindir}/nethack
%{_mandir}/man6/*
%dir %{_datadir}/games/nethack
%{_datadir}/games/nethack/license
%{_datadir}/games/nethack/nhdat
%dir %{_prefix}/lib/nethack
%attr(0755,-,-) %{_prefix}/lib/nethack/dgn_comp
%attr(0755,-,-) %{_prefix}/lib/nethack/dlb
%attr(0755,-,-) %{_prefix}/lib/nethack/lev_comp
%attr(0755,-,-) %{_prefix}/lib/nethack/makedefs
%attr(0755,-,-) %{_prefix}/lib/nethack/nethack
%attr(0755,-,-) %{_prefix}/lib/nethack/recover
%{_prefix}/lib/nethack/options
%dir %attr(0770,games,games) %{_localstatedir}/games/nethack
%dir %attr(0770,games,games) %{_localstatedir}/games/nethack/save
%config(noreplace) %attr(0660,games,games) %{_localstatedir}/games/nethack/logfile
%config(noreplace) %attr(0660,games,games) %{_localstatedir}/games/nethack/paniclog
%config(noreplace) %attr(0660,games,games) %{_localstatedir}/games/nethack/record
%attr(0660,games,games) %{_localstatedir}/games/nethack/perm

%changelog
* Tue Jul  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Add nethack-WINCHAIN-a-framework-allowing-multiple-processors-be.patch:
  Define preprocessor token UNUSED to mark unused variables. (boo#1245527)
- Add nethack-address-H4266-build-problem-with-clang-Modules.patch: Fix
  passing an incorrect function signature for signal handling.
  allmain.c: In function ‘newgame’:
  allmain.c:507:31: error: passing argument 2 of ‘signal’ from incompatible pointer type [-Wincompatible-pointer-types]
  507 |         (void) signal(SIGINT, (SIG_RET_TYPE) done1);
    |                               ^~~~~~~~~~~~~~~~~~~~
    |                               |
    |                               void (*)(void)
  The patch from upstream changes a number of things for OSX support,
  but we only take the fixes to signal handling. (boo#1245527)
- Add nethack-tty-xputc.patch: tputs() wants a callback that returns
  an integer. Backport upstream fix. (boo#1245527)
- Add nethack-gcc15-1.patch: Adopt upstream fix for NetHack 3.6 to
  the code base to make it build with Gcc 15. Reference avalable at
  https://nethack.org/v367/bugmore/gcc15-1.diff. (boo#1245527)
- Refresh patches on top of upstream backports.
* Tue Jul  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Start listing patches specific to openSUSE at offset 50. This leaves
  room for backports in the range below.
* Mon Mar 17 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config.patch: Define AUTOPICKUP_EXCEPTIONS to make
  autopickup more user friendly. It is usually preferable for players
  to not pick up items automatically. Exceptions are Zorkmids (i.e.,
  in-game money). The compile-time option AUTOPICKUP_EXCEPTIONS allows
  for configuring this at runtime.
* Mon Mar 17 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Fix package description: it's the 'Mazes of Menace' (plural).
* Fri Mar 14 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Add nethack-escapes-revamp.patch: Fix possible privilege escalation
  when parsing config file. Takens from upstream commit 612755bfb
  ("escapes() revamp"). (boo#1239138 CVE-2020-5253)
* Mon Jan 13 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Add an interesting and meaningful description to the package.
- Clarify package summary.
- Link to HTTPS URL.
* Sun Jan 12 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Filter no-%%check-section rpmlint warnings. There are no test cases
  for NetHack. (W: no-%%check-section)
* Sun Jan 12 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Filter zero-length rpmlint warnings. Several files are required to
  by empty. Filter them from the RPM linter. (E: zero-length)
* Sun Jan 12 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Do not install documentation files. We package these files from the
  dource directory No need to copy them into the build root.
* Sat Jan 11 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Set file attributes in %%files section. It is not possible to use
  'make install' for this package, so we have to install all files
  manually. Resolve the hodgepotch of install and %%attr commands by
  setting all file attributes in the %%files section.
* Sat Jan 11 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Do not install /etc/nethack directory. We do not packaged it and it
  does not contain any files.
* Wed Jan  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Add nethack-escape-char.patch: Split off from nethack-misc.patch,
  this patch contains a fix for input handling.
- Add nethack-secure.patch: Improve support for SECURE in recover
  utility. Does not affect the game binary. Taken from nethack-misc.patch.
- Modify nethack-config.patch: When patching Makefiles, also fix the
  paths in the documentation to match openSUSE systems.
- Drop nethack-misc.patch: The patch has been split and its content
  moved to other patch files.
* Wed Jan  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-gzip.patch: Point COMPRESS to /usr/bin/gzip and avoid
  the symlink /bin. The top-level /bin directory is supposed to go away.
* Wed Jan  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config.patch: The patch enabled building a number of
  files for X11, which we don't support. Remove them from the build.
* Wed Jan  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Drop nethack-syscall.patch: The patch only affects builds with GNOME
  support, which we don't do.
* Wed Jan  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Add nethack-reproducible.patch: Same as reproducible.patch, but
  follows patch-nameing conventions. There's now also a short patch
  description in the spec file.
- Drop reproducible.patch: Renamed to nethack-reproducible.patch.
* Wed Jan  8 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-syscall.patch: Refresh to account for offset changes.
- Modify nethack-gzip.patch: Refresh to account for offset changes.
* Tue Jan  7 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config: Enable panic logging. This records serious
  errors in the file panic log in the game's state directory. Helps
  with debugging.
* Mon Jan  6 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Mark NetHack's record and logfile file with %%config(noreplace), so
  that package updates do not overwrite existing highscores and
  information about previous games. Also list the various state files
  individually instead of lumping them together.
- Install 'logfile' instead of 'log' in NetHack's state directory. The
  file contains information about earlier played games.
* Fri Jan  3 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Avoid race around dlb.o (boo#1102408)
* Fri Jan  3 2025 Thomas Zimmermann <tzimmermann@suse.com>
- Implement parallel builds for all target. The Makefiles do not
  handle target dependencies correctly and parallel building does
  not work reliably by default. Hence we run several rules explicitly
  before 'all', which then uses the results. Guidebook.ps still has
  to be build separately.
- Build object files for makedefs first. Fixes possible linker errors
  on parallel builds. The Makefiles do not track the dependencies correctly.
  An example error is shown below.
  [    3s] cc  -o makedefs makedefs.o ../src/monst.o ../src/objects.o
  [    3s] ld: /tmp/cckee6qh.debug.temp.o: bad reloc symbol index (0x74727473 >= 0x8) for offset 0x6261747274732e00 in section `.debug_line'
  [    3s] ld: /tmp/cckee6qh.debug.temp.o: error adding symbols: bad value
  [    3s] collect2: error: ld returned 1 exit status
  (boo#1102408)
- Remove the unnecessary invocation of 'make clean'.
* Fri Jan  3 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Build nethack/monst.o in a more reproducible way (boo#1102408)
* Thu Dec 26 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Drop global config directory. NetHack does not read the global RC
  file any longer. Remove the rsp directory, usually /etc/nethack, from
  the package.
* Thu Dec 19 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Remove %%{_datadir}/games from files section. The directory is owned
  by the filesystem package and should not be packaged by nethack. Rpm
  will now install nethack without the --force option.
* Thu Dec 19 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Install nethack launch script in %%{_bindir}, so that users can run
  it from the commnd line. Also resolves an error were nethack package
  owned the standard directory /usr/games (E: standard-dir-owned-by-package).
* Thu Dec 19 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Remove nethackrc: Nethack's global rc file was a product of openSUSE's
  custom start script. With the removal of the script, nethack reads the
  .nethackrc in the user's home directory. This is standard behavior on
  Unix systems.
* Thu Dec 19 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Remove SuSE.tar.bz2: The files in the archive are outdated and no
  longer used for building NetHack.
* Thu Dec 19 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config.patch: Adapt sys/unix/nethack.sh to SUSE
  filesystem hierarchy. The script assumes that the NetHack binary is
  in the data directory. disstinuish between the two.
- Remove all remaining files from SuSE.tar.bz2 from the package. Use
  the up-to-date files that come with the release and patch them if
  necessary.
* Thu Dec 19 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Drop options.tty in favor of standard options files. As there is
  only ever one options file, drop the extension.
* Thu Dec 19 2024 Thomas Zimmermann <tzimmermann@suse.com>
- List games user and group as PreReq
* Wed Dec 18 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Remove graphical features, such as tiles, XPM files and X11 utils
  from the package. The TTY build does not use them.
* Wed Dec 18 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Mark license file with %%fdupes. The file serves as data file for
  the NetHack binary, but is also installed via %%license. %%fdupes does
  not actually support de-duplicating if %%license is involved. But at
  least it is listed correctly. (W: files-duplicate)
* Wed Dec 18 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Drop 'recover-helper' as it is a trivial helper around the recover
  utility.
* Tue Dec 17 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Copy nethackrc.tty from SuSE.tar.bz2 to source directory and
  list is as Source2. Rename to nethackrc.
- Reduce nethackrc to non-default options. Drop 'number_pad' to make
  the game playable on notebooks, which often don't have numpads.
* Tue Dec 17 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Remove TeXLive from BuildRequires. It's not needed as we don't
  build the Guidebook DVI.
* Tue Dec 17 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Do not pack fixes (i.e., change logs) files in a tar archive when
  installing them. It has been a long time since packing up change
  logs was necessary for saving disk space.
* Fri Dec  6 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config.patch: Add Guidebook.ps to the package. We
  generate this document from the doc/ folder. There's still
  Guidebook.txt as before for users without PostScript reader.
- Drop Guidebook.tex from package. The tex file is an input file for
  documentation. Don't add it to the package.
* Fri Dec  6 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Drop README.SuSE from package. The README is completely outdated,
  thus remove it from the package. Also resolves a warning about the
  incorrect capitalization in 'SuSE.' (E: wrong-suse-capitalisation)
* Fri Dec  6 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Add groff to build requirements. Fixes a build warning where tbl and
  nroff are not available.
* Fri Dec  6 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Remove CFLAGS from invocations of make. We patch the Makefiles with
  appropriate compile flags and sed-in any %%{optflags}. No need to
  pass additional flags while invoking make. Also drop _GNU_SOURCE
  while at it; it's not required for the build.
* Fri Dec  6 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config.patch: Integrate SuSE/tty/Makefile.src into
  this patch instead of copying it. Reduce the changes to the minimum.
  Only rename nethack to nethack.tty and set compiler and linker flags.
  As SuSE/tty/Makefile.src was for an older version of nethack, it
  did not list all source dependencies correctly, hence leading to
  sporadic compile errors. Patching the actual Makefile fixes this.
- Copy Makefiles from sys/unix/ to their places instead of symlinking
  them; then run sed to add optimization flags. Fixes another problem
  with the outdated Makefile from SuSE/tty/.
* Tue Dec  3 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config.patch: Update the config file strictly to the
  upstream state plus changes for the SUSE TTY build. The config file
  coming from SuSE.tar.bz2 refered to an older upstream release.
* Tue Dec  3 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-config.patch: Integrate SuSE/tty/config.h into this
  patch instead of copying it; except for the COMPRESS settings, which
  nethack-gzip.patch still updates. We never build anything else than
  the TTY variant of nethack, so there's no point in keeping these
  config changes in various places.
* Tue Dec  3 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Drop references to /usr/X11R6/ from build flags. We're not building
  for X11 any longer and that directory has been gone for years anyway.
* Sun Dec  1 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Don't make configuration files in /etc/nethack executable.
  (E: script-without-shebang)
* Sun Dec  1 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Don't make game-state files in /var/games/nethack executable.
  (W: script-without-shebang)
* Sat Nov 30 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Modify nethack-misc.patch: Refresh to fix patch offsets.
* Sat Nov 30 2024 Thomas Zimmermann <tzimmermann@suse.com>
- Replace deprecated %%patchN macros with %%patch -PN
  (E: patch-macro-old-format)
* Sat Aug 10 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Create fixes.tar.bz2 in a reproducible way
- Add reproducible.patch to not add build date into binary
  to make package build reproducible (boo#1047218)
* Tue Jul 16 2019 Adam Majer <adam.majer@suse.de>
- Own installed directories and thus fix building
- Fix license
* Mon Mar 25 2013 joop.boonen@opensuse.org
- Corrected the License
* Thu Jan 24 2013 joop.boonen@opensuse.org
- run_permissions was replaced by set_permissions
  http://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros#.25set_permissions
* Thu Jan 17 2013 joop.boonen@opensuse.org
- run_permissions is obsolete, not supported in openSUSE > 12.2
- cleaned the spec file up
* Sat Mar 24 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant spec sections
* Mon Jan 16 2012 pgajdos@suse.com
- improved start script [bnc#741605]
* Mon Aug  3 2009 gerberb@zenez.com
- Second attempt at a fix.
* Mon Aug  3 2009 gerberb@zenez.com
- Attempt to get things working once things were moved from games:roleplaying to
  just games but had the wrong nethack.changes file.
* Wed Sep 13 2006 gerberb@zenez.com
- setup and fixed to build on OBS
* Thu May 25 2006 gerberb@zenez.com
- fixed spec file
* Tue Feb 14 2006 mmarek@suse.cz
- use /usr/lib/nethack instead of /usr/%%%%_lib/nethack, because we
  don't install any libraries there and /etc/permissions* contains
  /usr/lib/nethack
  [#140336]
- build as user
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri May  6 2005 sbrabec@suse.cz
- Fixed duplicated declarations.
- Build with correct CFLAGS.
* Thu Jan 20 2005 ro@suse.de
- drop nethack-qt, gnomehack, xnethack
- re-unite nethack and nethack-common
* Wed Nov 10 2004 ro@suse.de
- reduced neededforbuild
* Thu Sep 30 2004 sbrabec@suse.cz
- Biarch path fix (#31938).
* Mon Feb  9 2004 sbrabec@suse.cz
- Updated to version 3.4.3.
* Wed Nov  5 2003 ro@suse.de
- package according to permissions.secure and add run_permissions
* Mon Sep  1 2003 sbrabec@suse.cz
- Updated to version 3.4.2 (bug #29803).
* Thu Jun 12 2003 coolo@suse.de
- fiddle with %%_docdir
* Sat Jun  7 2003 coolo@suse.de
- compile with latest Qt
- remove buildroot before installing
- package /usr/games/nethack (as installed explicitly)
* Thu Feb 27 2003 sbrabec@suse.cz
- Use gzip instead of compress for compression (bug #22454).
* Wed Feb 26 2003 sbrabec@suse.cz
- Security fix (local buffer overflow).
* Mon Feb 17 2003 sbrabec@suse.cz
- Removed -mminimal-toc from spec file for PPC, since it is now RPM
  default (bug #23266).
* Wed Oct 23 2002 mcihar@suse.cz
- enabled data librarian
- added X11 version
- Qt version renamed to nethack-qt (from xnethack) and built against qt3
  (qt-mt)
- different styles (tty/Qt/Gnome/X11) do not conflict
- new lanching script nethack, ui can be chosen by environment variable
  HACKSTYLE=x11/qt/gnome/tty
- cleaned neededforbuild
- included some tools into nethack-common (was nethack_data)
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Thu Sep 12 2002 kukuk@suse.de
- Add missing obsolete from package rename
* Wed Aug 21 2002 mcihar@suse.cz
- added PreReqs
* Sun Jul 28 2002 kukuk@suse.de
- change group game to games
* Tue Jul 16 2002 mcihar@suse.cz
- nh_data renamed to nethack_data
- nh_binary renamed to nethack_binary
- updated nethack_data description to mention gnomehack also
* Mon Jul  1 2002 olh@suse.de
- build with -mminimal-toc on ppc64
* Thu Jun  6 2002 prehak@suse.de
- fixed for ia64
  - using of macro _syscall3 replaced with ordinary system call
  - kernel header linux/unistd.h replaced with unistd.h
* Fri May 31 2002 prehak@suse.de
- fixed to build on x86_64 and s390x
* Thu May 16 2002 prehak@suse.cz
- updated to new version 3.4.0
* Mon Jan 21 2002 tcrhak@suse.cz
- fixed include dir path for gnome
* Mon Jan 14 2002 tcrhak@suse.cz
- moved static data to /usr/share/games/nethack
- and executables to /usr/lib/nethack (FHS 2.2)
* Fri Nov  9 2001 ro@suse.de
- use qt-devel-packages in neededforbuild
* Mon Sep  3 2001 schwab@suse.de
- Fix conflicting declaration.
* Sun Mar 18 2001 ro@suse.de
- fixed neededforbuild
* Thu Mar  8 2001 uli@suse.de
- added xf86 to neededforbuild
- replaced static GTK include paths with "gtk-config --cflags"
* Thu Jan 25 2001 vinil@suse.cz
- upgraded to 3.3.1
- difs split and cleanup
- gnome version included
* Tue Jan 23 2001 schwab@suse.de
- Fix conflicting declarations.
* Thu Nov 30 2000 ro@suse.de
- neededforbuild += liblcms
* Fri Nov 17 2000 ro@suse.de
- fixed neededforbuild: += libmng-devel
* Sun Nov  5 2000 kukuk@suse.de
- adjust neededforbuild
* Fri Oct 20 2000 ro@suse.de
- added libmng to neededforbuild
* Tue Aug 22 2000 vinil@suse.cz
- mesa, mesasoft added to neededforbuild
* Tue Jul 18 2000 vinil@suse.cz
- Alt (Meta) key should work now in tty version, too
  (are there any problems with it?)
* Fri Jun 23 2000 vinil@suse.cz
- doc files relocated
* Tue Jun 20 2000 vinil@suse.cz
- major file relocation
- nethackrc demofile added
* Tue Jun 13 2000 vinil@suse.cz
- nethack and xnethack are two frontends now
- nh_data is needed for both
* Sat Feb 19 2000 kasal@suse.cz
- upgraded to 3.3.0
- added BuildRoot
- moved manpages to /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jun 11 1997 rj@suse.de
- new version 3.2.2
